@@ -108,6 +108,15 @@ from .namespaces.oracle import (
     VADState,
 )
 
+# Export AI namespace for agent-runtime operations
+from .namespaces.ai import (
+    AiNamespace,
+    RagSubNamespace,
+    ArtifactsSubNamespace,
+    ResultsSubNamespace,
+    WorkflowSubNamespace,
+)
+
 # Export cache and resilience utilities
 from .helpers.cache import (
     dominus_cache,
@@ -131,7 +140,7 @@ from .errors import (
     TimeoutError as DominusTimeoutError,
 )
 
-__version__ = "2.5.4"
+__version__ = "2.7.0"
 __all__ = [
     # Main SDK instance
     "dominus",
@@ -165,6 +174,12 @@ __all__ = [
     "OracleSession",
     "OracleSessionOptions",
     "VADState",
+    # AI namespace for agent-runtime operations
+    "AiNamespace",
+    "RagSubNamespace",
+    "ArtifactsSubNamespace",
+    "ResultsSubNamespace",
+    "WorkflowSubNamespace",
     # Cache and resilience utilities
     "dominus_cache",
     "CircuitBreaker",
