@@ -61,20 +61,24 @@ def _decode_jwt_payload(jwt: str) -> dict:
 
 async def _get_service_jwt(psk_token: str, base_url: str) -> str:
     """
-    Get service JWT by calling /api/warden/mint with PSK.
+    Get service JWT by calling gateway /jwt/mint with PSK.
 
     Uses circuit breaker to prevent retry storms during service outages.
+    Retries on 401/5xx with exponential backoff (gateway cold start handling).
 
     Args:
         psk_token: PSK token (DOMINUS_TOKEN)
-        base_url: Orchestrator base URL
+        base_url: Ignored (uses gateway URL from config)
 
     Returns:
         JWT token string
 
     Raises:
-        RuntimeError: If circuit is open or auth fails
+        RuntimeError: If circuit is open or auth fails after retries
     """
+    from ..config.endpoints import get_gateway_url
+    gateway_url = get_gateway_url()
+
     # Circuit breaker check
     if not sovereign_circuit_breaker.can_execute():
         raise RuntimeError(
@@ -90,36 +94,89 @@ async def _get_service_jwt(psk_token: str, base_url: str) -> str:
         "Content-Type": "text/plain"
     }
 
-    # Body format for warden/mint endpoint
+    # Body format for gateway /jwt/mint endpoint
     body_json = {"method": "auth.self", "params": {}}
     body_b64 = _b64_encode(body_json)
 
-    try:
-        async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30.0) as client:
-            response = await client.post("/api/warden/mint", content=body_b64)
-            response.raise_for_status()
+    # Retry loop for JWT minting (handles gateway cold start)
+    JWT_MINT_RETRIES = 3
+    last_error = None
 
-            # Decode base64 response
-            result = _b64_decode(response.text)
+    for attempt in range(JWT_MINT_RETRIES):
+        try:
+            async with httpx.AsyncClient(base_url=gateway_url, headers=headers, timeout=30.0) as client:
+                response = await client.post("/jwt/mint", content=body_b64)
 
-            if not result.get("success"):
-                error_msg = result.get("error", "Unknown auth error")
+                # Check for retryable status codes before raise_for_status
+                if response.status_code == 401 or response.status_code >= 500:
+                    if attempt < JWT_MINT_RETRIES - 1:
+                        delay = exponential_backoff_with_jitter(attempt, base_delay=2.0, max_delay=10.0)
+                        print(
+                            f"[Dominus] JWT mint returned {response.status_code}, "
+                            f"retrying in {delay:.1f}s (attempt {attempt + 1}/{JWT_MINT_RETRIES})"
+                        )
+                        await asyncio.sleep(delay)
+                        continue
+
+                response.raise_for_status()
+
+                # Decode base64 response
+                result = _b64_decode(response.text)
+
+                if not result.get("success"):
+                    error_msg = result.get("error", "Unknown auth error")
+                    sovereign_circuit_breaker.record_failure()
+                    raise RuntimeError(f"Auth error: {error_msg}")
+
+                data = result.get("data", {})
+                jwt = data.get("access_token") or data.get("token")
+                if not jwt:
+                    sovereign_circuit_breaker.record_failure()
+                    raise RuntimeError("No JWT token in auth response")
+
+                # Success - record it
+                sovereign_circuit_breaker.record_success()
+                return jwt
+
+        except httpx.TimeoutException as e:
+            last_error = e
+            if attempt < JWT_MINT_RETRIES - 1:
+                delay = exponential_backoff_with_jitter(attempt, base_delay=2.0, max_delay=10.0)
+                print(
+                    f"[Dominus] JWT mint timed out, "
+                    f"retrying in {delay:.1f}s (attempt {attempt + 1}/{JWT_MINT_RETRIES})"
+                )
+                await asyncio.sleep(delay)
+                continue
+            sovereign_circuit_breaker.record_failure()
+            raise RuntimeError(f"Failed to get JWT: {e}") from e
+
+        except httpx.NetworkError as e:
+            last_error = e
+            if attempt < JWT_MINT_RETRIES - 1:
+                delay = exponential_backoff_with_jitter(attempt, base_delay=2.0, max_delay=10.0)
+                print(
+                    f"[Dominus] JWT mint network error ({e}), "
+                    f"retrying in {delay:.1f}s (attempt {attempt + 1}/{JWT_MINT_RETRIES})"
+                )
+                await asyncio.sleep(delay)
+                continue
+            sovereign_circuit_breaker.record_failure()
+            raise RuntimeError(f"Failed to get JWT: {e}") from e
+
+        except httpx.HTTPStatusError as e:
+            last_error = e
+            # 4xx errors (except 401 which is retried above) should not be retried
+            if 400 <= e.response.status_code < 500 and e.response.status_code != 401:
                 sovereign_circuit_breaker.record_failure()
-                raise RuntimeError(f"Auth error: {error_msg}")
+                raise RuntimeError(f"Failed to get JWT: {e}") from e
+            # For other errors, we've already handled retries in the status check above
+            sovereign_circuit_breaker.record_failure()
+            raise RuntimeError(f"Failed to get JWT: {e}") from e
 
-            data = result.get("data", {})
-            jwt = data.get("access_token") or data.get("token")
-            if not jwt:
-                sovereign_circuit_breaker.record_failure()
-                raise RuntimeError("No JWT token in auth response")
-
-            # Success - record it
-            sovereign_circuit_breaker.record_success()
-            return jwt
-
-    except (httpx.TimeoutException, httpx.NetworkError, httpx.HTTPStatusError) as e:
-        sovereign_circuit_breaker.record_failure()
-        raise RuntimeError(f"Failed to get JWT: {e}") from e
+    # Should not reach here, but just in case
+    sovereign_circuit_breaker.record_failure()
+    raise RuntimeError(f"Failed to get JWT after {JWT_MINT_RETRIES} retries: {last_error}")
 
 
 def _get_architect_url(psk_token: str = None, sovereign_url: str = None, environment: str = None) -> str:
@@ -187,7 +244,7 @@ async def _ensure_valid_jwt(psk_token: str, sovereign_url: str) -> str:
 def verify_token_format(token: str) -> bool:
     """
     Verify token format is valid (basic check, not server verification).
-    Actual token validation happens when we call /api/warden/mint.
+    Actual token validation happens when we call gateway /jwt/mint.
 
     Args:
         token: Auth token to verify
@@ -557,17 +614,20 @@ async def _execute_auth_call(
     **kwargs
 ) -> DominusResponse:
     """
-    Execute an auth call to /api/warden/* endpoints.
+    Execute an auth call to gateway /jwt/* endpoints.
 
     Args:
         method: Auth method name (e.g., "auth.mint", "auth.jwks")
         psk_token: PSK token (DOMINUS_TOKEN) - None for public endpoints like auth.jwks
-        base_url: Orchestrator base URL
+        base_url: Ignored (uses gateway URL from config)
         **kwargs: Method parameters
 
     Returns:
         Response data
     """
+    from ..config.endpoints import get_gateway_url
+    gateway_url = get_gateway_url()
+
     headers = {
         "Content-Type": "text/plain"
     }
@@ -580,16 +640,20 @@ async def _execute_auth_call(
     body_json = {"method": method, "params": kwargs}
     body_b64 = _b64_encode(body_json)
 
-    # Map method to endpoint
+    # Map method to gateway endpoint
     if method == "auth.jwks":
-        endpoint = "/api/warden/jwks"
+        endpoint = "/jwt/jwks"
     elif method == "auth.mint":
-        endpoint = "/api/warden/mint"
+        endpoint = "/jwt/mint"
     else:
-        endpoint = "/api/warden/mint"
+        endpoint = "/jwt/mint"
 
-    async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30.0) as client:
-        response = await client.post(endpoint, content=body_b64)
+    async with httpx.AsyncClient(base_url=gateway_url, headers=headers, timeout=30.0) as client:
+        # JWKS uses GET (public endpoint), other auth endpoints use POST
+        if method == "auth.jwks":
+            response = await client.get(endpoint)
+        else:
+            response = await client.post(endpoint, content=body_b64)
         response.raise_for_status()
 
         # Decode base64 response
