@@ -349,6 +349,10 @@ class Dominus:
         # Alias for Node.js SDK parity (stt = oracle)
         self.stt = self.oracle
 
+        # AI namespace (agent-runtime unified API)
+        from .namespaces.ai import AiNamespace
+        self.ai = AiNamespace(self)
+
         # Cache for JWT public key
         self._public_key_cache = None
 
@@ -445,6 +449,185 @@ class Dominus:
 
         return result.get("data", {})
 
+    async def _stream_request(
+        self,
+        endpoint: str,
+        body: Optional[Dict[str, Any]] = None,
+        on_chunk: Optional[Any] = None,
+        timeout: float = 300.0
+    ):
+        """
+        Make an SSE streaming request to the orchestrator.
+
+        Args:
+            endpoint: API endpoint path (e.g., "/api/agent/stream")
+            body: Request body (will be base64-encoded)
+            on_chunk: Optional callback for each chunk
+            timeout: Request timeout in seconds (default: 300s for long operations)
+
+        Yields:
+            Parsed JSON chunks from SSE stream
+        """
+        global _VALIDATED
+
+        # Base64 helpers
+        def _b64_encode(d: dict) -> str:
+            return base64.b64encode(json.dumps(d).encode()).decode()
+
+        # Validate and get JWT
+        if _VALIDATION_ERROR:
+            raise RuntimeError(_VALIDATION_ERROR)
+
+        if not _VALIDATED:
+            from .helpers.core import verify_token_format, health_check_all
+            verify_token_format(_TOKEN)
+            result = await health_check_all(_BASE_URL)
+            if result["status"] != "healthy" and result["status"] != "ok":
+                raise RuntimeError(f"Services unhealthy: {result['message']}")
+            _VALIDATED = True
+
+        from .helpers.core import _ensure_valid_jwt
+        jwt = await _ensure_valid_jwt(_TOKEN, _BASE_URL)
+
+        headers = {
+            "Authorization": f"Bearer {jwt}",
+            "Content-Type": "text/plain",
+            "Accept": "text/event-stream"
+        }
+
+        body_b64 = _b64_encode(body or {})
+
+        from .helpers.sse import stream_sse
+
+        async with httpx.AsyncClient(base_url=_BASE_URL, timeout=timeout) as client:
+            async with client.stream("POST", endpoint, content=body_b64, headers=headers) as response:
+                response.raise_for_status()
+                async for chunk in stream_sse(response, on_chunk):
+                    yield chunk
+
+    async def _binary_upload(
+        self,
+        endpoint: str,
+        file_bytes: bytes,
+        filename: str,
+        content_type: str = "application/octet-stream",
+        additional_fields: Optional[Dict[str, str]] = None,
+        timeout: float = 60.0
+    ) -> Dict[str, Any]:
+        """
+        Upload binary file via multipart/form-data (no base64 encoding).
+
+        Used for audio uploads (STT) and other binary file uploads.
+
+        Args:
+            endpoint: API endpoint path (e.g., "/api/agent/stt")
+            file_bytes: Raw binary file content
+            filename: Filename for the upload
+            content_type: MIME type (default: application/octet-stream)
+            additional_fields: Optional additional form fields
+            timeout: Request timeout in seconds
+
+        Returns:
+            Response data dict
+        """
+        global _VALIDATED
+
+        def _b64_decode(s: str) -> dict:
+            return json.loads(base64.b64decode(s.encode('utf-8')).decode('utf-8'))
+
+        if _VALIDATION_ERROR:
+            raise RuntimeError(_VALIDATION_ERROR)
+
+        if not _VALIDATED:
+            from .helpers.core import verify_token_format, health_check_all
+            verify_token_format(_TOKEN)
+            result = await health_check_all(_BASE_URL)
+            if result["status"] != "healthy" and result["status"] != "ok":
+                raise RuntimeError(f"Services unhealthy: {result['message']}")
+            _VALIDATED = True
+
+        from .helpers.core import _ensure_valid_jwt
+        jwt = await _ensure_valid_jwt(_TOKEN, _BASE_URL)
+
+        headers = {
+            "Authorization": f"Bearer {jwt}"
+        }
+
+        # Build multipart form data
+        files = {"file": (filename, file_bytes, content_type)}
+        data = additional_fields or {}
+
+        async with httpx.AsyncClient(base_url=_BASE_URL, headers=headers, timeout=timeout) as client:
+            response = await client.post(endpoint, files=files, data=data)
+
+        response.raise_for_status()
+
+        # Response may be base64-encoded JSON or raw JSON
+        try:
+            result = _b64_decode(response.text)
+        except Exception:
+            result = response.json()
+
+        if isinstance(result, dict) and not result.get("success", True):
+            error_msg = result.get("error", "Unknown error")
+            raise RuntimeError(f"Upload error: {error_msg}")
+
+        return result.get("data", result) if isinstance(result, dict) else result
+
+    async def _binary_download(
+        self,
+        endpoint: str,
+        body: Optional[Dict[str, Any]] = None,
+        timeout: float = 60.0
+    ) -> bytes:
+        """
+        Download binary content (no base64 encoding in response).
+
+        Used for TTS audio responses and other binary downloads.
+
+        Args:
+            endpoint: API endpoint path (e.g., "/api/agent/tts")
+            body: Request body (will be base64-encoded for auth)
+            timeout: Request timeout in seconds
+
+        Returns:
+            Raw binary bytes
+        """
+        global _VALIDATED
+
+        def _b64_encode(d: dict) -> str:
+            return base64.b64encode(json.dumps(d).encode()).decode()
+
+        if _VALIDATION_ERROR:
+            raise RuntimeError(_VALIDATION_ERROR)
+
+        if not _VALIDATED:
+            from .helpers.core import verify_token_format, health_check_all
+            verify_token_format(_TOKEN)
+            result = await health_check_all(_BASE_URL)
+            if result["status"] != "healthy" and result["status"] != "ok":
+                raise RuntimeError(f"Services unhealthy: {result['message']}")
+            _VALIDATED = True
+
+        from .helpers.core import _ensure_valid_jwt
+        jwt = await _ensure_valid_jwt(_TOKEN, _BASE_URL)
+
+        headers = {
+            "Authorization": f"Bearer {jwt}",
+            "Content-Type": "text/plain",
+            "Accept": "audio/*"
+        }
+
+        body_b64 = _b64_encode(body or {})
+
+        async with httpx.AsyncClient(base_url=_BASE_URL, headers=headers, timeout=timeout) as client:
+            response = await client.post(endpoint, content=body_b64)
+
+        response.raise_for_status()
+
+        # Return raw binary content
+        return response.content
+
     # ========================================
     # SECRETS (root level)
     # ========================================
